==> gammaray_2.4.1.orig.tar.gz: gammaray-2.4.1/plugins/positioning/positioning.h <==
/*
  positioning.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_POSITIONING_H
#define GAMMARAY_POSITIONING_H

#include <core/toolfactory.h>

#include <QGeoPositionInfoSource>
#include <QObject>

namespace GammaRay {

class Positioning : public QObject
{
    Q_OBJECT
public:
    explicit Positioning(ProbeInterface *probe, QObject *parent = Q_NULLPTR);
};

class PositioningFactory :  public QObject, public StandardToolFactory<QGeoPositionInfoSource, Positioning>
{
    Q_OBJECT
    Q_INTERFACES(GammaRay::ToolFactory)
    Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_positioning.json")
public:
    explicit PositioningFactory(QObject *parent = Q_NULLPTR) : QObject(parent)
    {
    }

    QString name() const Q_DECL_OVERRIDE;
};

}

#endif // GAMMARAY_POSITIONING_H

==> gammaray_2.8.1.orig.tar.gz: gammaray-2.8.1/plugins/positioning/positioning.h <==
/*
  positioning.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_POSITIONING_H
#define GAMMARAY_POSITIONING_H

#include <core/toolfactory.h>

#include <QGeoPositionInfoSource>
#include <QObject>

namespace GammaRay {
class Positioning : public QObject
{
    Q_OBJECT
public:
    explicit Positioning(ProbeInterface *probe, QObject *parent = nullptr);
};

class PositioningFactory : public QObject,
    public StandardToolFactory<QGeoPositionInfoSource, Positioning>
{
    Q_OBJECT
    Q_INTERFACES(GammaRay::ToolFactory)
    Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_positioning.json")
public:
    explicit PositioningFactory(QObject *parent = nullptr)
        : QObject(parent)
    {
    }
};
}

#endif // GAMMARAY_POSITIONING_H
